@@ -20,6 +20,7 @@ tab-size = 4
 #include <atomic>
 #include <filesystem>
 #include <fstream>
+#include <locale>
 #include <optional>
 #include <ranges>
 #include <string_view>
@@ -131,6 +132,8 @@ namespace Config {
 
 		{"show_uptime", 		"#* Shows the system uptime in the CPU box."},
 
+		{"show_cpu_watts",		"#* Shows the CPU package current power consumption in watts. Requires running `make setcap` or `make setuid` or running with sudo."},
+
 		{"check_temp", 			"#* Show cpu temperature."},
 
 		{"cpu_sensor", 			"#* Which sensor to use for cpu temperature, use options menu to select from list of available sensors."},
@@ -280,6 +283,7 @@ namespace Config {
 		{"cpu_single_graph", false},
 		{"cpu_bottom", false},
 		{"show_uptime", true},
+		{"show_cpu_watts", true},
 		{"check_temp", true},
 		{"show_coretemp", true},
 		{"show_cpu_freq", true},
@@ -471,7 +475,11 @@ namespace Config {
 			} else if (vals.at(0) == "proc") {
 				set("proc_left", (vals.at(1) != "0"));
 			}
-			set("graph_symbol_" + vals.at(0), vals.at(2));
+			if (vals.at(0).starts_with("gpu")) {
+				set("graph_symbol_gpu", vals.at(2));
+			} else {
+				set("graph_symbol_" + vals.at(0), vals.at(2));
+			}
 		}
 
 		if (set_boxes(boxes)) {
@@ -764,6 +772,7 @@ namespace Config {
 		Logger::debug("Writing new config file");
 		if (geteuid() != Global::real_uid and seteuid(Global::real_uid) != 0) return;
 		std::ofstream cwrite(conf_file, std::ios::trunc);
+		cwrite.imbue(std::locale::classic());
 		if (cwrite.good()) {
 			cwrite << "#? Config file for btop v. " << Global::Version << "\n";
 			for (const auto& [name, description] : descriptions) {
